package de.szut.lf8_starter.project.action.employee;

import de.szut.lf8_starter.project.ProjectEntity;
import de.szut.lf8_starter.project.ProjectService;
import de.szut.lf8_starter.security.AccessTokenService;
import org.springframework.http.*;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.client.RestTemplate;

import java.util.Optional;

@RestController
public class AddEmployeeToProjectAction {
    private final ProjectService projectService;
    private final AccessTokenService accessTokenService;
    private final RestTemplate restTemplate;

    public AddEmployeeToProjectAction(ProjectService projectService, AccessTokenService accessTokenService, RestTemplate restTemplate) {
        this.projectService = projectService;
        this.accessTokenService = accessTokenService;
        this.restTemplate = restTemplate;
    }


    @PostMapping("/projects/{projectId}/employees/{employeeId}")
    public ResponseEntity<Object> create(@PathVariable Long projectId, @PathVariable Long employeeId) {
        Optional<ProjectEntity> project = this.projectService.findById(projectId);

        if (project.isEmpty()) {
            return new ResponseEntity<>(HttpStatus.NOT_FOUND);
        }

        String accessToken = this.accessTokenService.getAccessToken();

        HttpHeaders headers = new HttpHeaders();
        headers.setBearerAuth(accessToken);

        HttpEntity<String> requestEntity = new HttpEntity<>(headers);

        String url = "https://employee.szut.dev/employees/" + employeeId;
        ResponseEntity<String> response = restTemplate.exchange(url, HttpMethod.GET, requestEntity, String.class);

        System.out.println("Employee Data: " + response.getBody());
        
        return new ResponseEntity<>(HttpStatus.NO_CONTENT);
    }
}
